# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/object_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.models.v1 import query_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2aruna/api/storage/services/v1/object_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\'aruna/api/storage/models/v1/query.proto\x1a\x1cgoogle/api/annotations.proto\"\x17\n\x03URL\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"\x90\x03\n\x0bStageObject\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1f\n\x0b\x63ontent_len\x18\x04 \x01(\x03R\ncontentLen\x12;\n\x06source\x18\x05 \x01(\x0b\x32#.aruna.api.storage.models.v1.SourceR\x06source\x12\x44\n\tdataclass\x18\x06 \x01(\x0e\x32&.aruna.api.storage.models.v1.DataClassR\tdataclass\x12=\n\x06labels\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x08 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\"\x82\x02\n\x1aInitializeNewObjectRequest\x12\x42\n\x06object\x18\x01 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x32\n\x15preferred_endpoint_id\x18\x04 \x01(\tR\x13preferredEndpointId\x12\x1c\n\tmultipart\x18\x05 \x01(\x08R\tmultipart\x12)\n\x10is_specification\x18\x06 \x01(\x08R\x0fisSpecification\"|\n\x1bInitializeNewObjectResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\"\xb3\x01\n\x13GetUploadURLRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1c\n\tmultipart\x18\x04 \x01(\x08R\tmultipart\x12\x1f\n\x0bpart_number\x18\x05 \x01(\x05R\npartNumber\"L\n\x14GetUploadURLResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"8\n\x0e\x43ompletedParts\x12\x12\n\x04\x65tag\x18\x01 \x01(\tR\x04\x65tag\x12\x12\n\x04part\x18\x02 \x01(\x03R\x04part\"Y\n\x15GetDownloadURLRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"N\n\x16GetDownloadURLResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"]\n\x1cGetDownloadLinksBatchRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x18\n\x07objects\x18\x02 \x03(\tR\x07objects\"W\n\x1dGetDownloadLinksBatchResponse\x12\x36\n\x04urls\x18\x01 \x03(\x0b\x32\".aruna.api.storage.services.v1.URLR\x04urls\"a\n CreateDownloadLinksStreamRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x18\n\x07objects\x18\x02 \x03(\tR\x07objects\"Y\n!CreateDownloadLinksStreamResponse\x12\x34\n\x03url\x18\x01 \x01(\x0b\x32\".aruna.api.storage.services.v1.URLR\x03url\"\xc8\x02\n\x1a\x46inishObjectStagingRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x35\n\x04hash\x18\x04 \x01(\x0b\x32!.aruna.api.storage.models.v1.HashR\x04hash\x12\x1b\n\tno_upload\x18\x05 \x01(\x08R\x08noUpload\x12V\n\x0f\x63ompleted_parts\x18\x06 \x03(\x0b\x32-.aruna.api.storage.services.v1.CompletedPartsR\x0e\x63ompletedParts\x12\x1f\n\x0b\x61uto_update\x18\x07 \x01(\x08R\nautoUpdate\"Z\n\x1b\x46inishObjectStagingResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\xcb\x02\n\x13UpdateObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x42\n\x06object\x18\x03 \x01(\x0b\x32*.aruna.api.storage.services.v1.StageObjectR\x06object\x12\x1a\n\x08reupload\x18\x04 \x01(\x08R\x08reupload\x12\x32\n\x15preferred_endpoint_id\x18\x05 \x01(\tR\x13preferredEndpointId\x12\x1d\n\nmulti_part\x18\x06 \x01(\x08R\tmultiPart\x12)\n\x10is_specification\x18\x07 \x01(\x08R\x0fisSpecification\x12\x14\n\x05\x66orce\x18\x08 \x01(\x08R\x05\x66orce\"w\n\x14UpdateObjectResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1d\n\nstaging_id\x18\x02 \x01(\tR\tstagingId\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\"\xd1\x01\n\x1c\x43reateObjectReferenceRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x30\n\x14target_collection_id\x18\x03 \x01(\tR\x12targetCollectionId\x12\x1c\n\twriteable\x18\x04 \x01(\x08R\twriteable\x12\x1f\n\x0b\x61uto_update\x18\x05 \x01(\x08R\nautoUpdate\"\x1f\n\x1d\x43reateObjectReferenceResponse\"\x88\x01\n\x12\x43loneObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x30\n\x14target_collection_id\x18\x03 \x01(\tR\x12targetCollectionId\"R\n\x13\x43loneObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x94\x01\n\x13\x44\x65leteObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x16\n\x14\x44\x65leteObjectResponse\"\x97\x01\n\x14\x44\x65leteObjectsRequest\x12\x1d\n\nobject_ids\x18\x01 \x03(\tR\tobjectIds\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\x12\x14\n\x05\x66orce\x18\x04 \x01(\x08R\x05\x66orce\"\x17\n\x15\x44\x65leteObjectsResponse\"^\n\rObjectWithURL\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\"s\n\x14GetObjectByIDRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"]\n\x15GetObjectByIDResponse\x12\x44\n\x06object\x18\x01 \x01(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x06object\"\xf5\x01\n\x11GetObjectsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12K\n\x0cpage_request\x18\x02 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12S\n\x0flabel_id_filter\x18\x03 \x01(\x0b\x32+.aruna.api.storage.models.v1.LabelOrIDQueryR\rlabelIdFilter\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"\\\n\x12GetObjectsResponse\x12\x46\n\x07objects\x18\x01 \x03(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x07objects\"\xc5\x01\n\x19GetObjectRevisionsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12\x19\n\x08with_url\x18\x04 \x01(\x08R\x07withUrl\"d\n\x1aGetObjectRevisionsResponse\x12\x46\n\x07objects\x18\x01 \x03(\x0b\x32,.aruna.api.storage.services.v1.ObjectWithURLR\x07objects\"b\n\x1eGetLatestObjectRevisionRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"^\n\x1fGetLatestObjectRevisionResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"]\n\x19GetObjectEndpointsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\"a\n\x1aGetObjectEndpointsResponse\x12\x43\n\tendpoints\x18\x01 \x03(\x0b\x32%.aruna.api.storage.models.v1.EndpointR\tendpoints\"\xa7\x01\n\x18\x41\x64\x64LabelsToObjectRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12I\n\rlabels_to_add\x18\x03 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x0blabelsToAdd\"X\n\x19\x41\x64\x64LabelsToObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x98\x01\n\x17SetHooksOfObjectRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12;\n\x05hooks\x18\x03 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\"W\n\x18SetHooksOfObjectResponse\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\"\x7f\n\x14GetReferencesRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\"\x9f\x01\n\x0fObjectReference\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\'\n\x0frevision_number\x18\x03 \x01(\x03R\x0erevisionNumber\x12!\n\x0cis_writeable\x18\x04 \x01(\x08R\x0bisWriteable\"g\n\x15GetReferencesResponse\x12N\n\nreferences\x18\x01 \x03(\x0b\x32..aruna.api.storage.services.v1.ObjectReferenceR\nreferences2\x88\x1e\n\rObjectService\x12\xbe\x01\n\x13InitializeNewObject\x12\x39.aruna.api.storage.services.v1.InitializeNewObjectRequest\x1a:.aruna.api.storage.services.v1.InitializeNewObjectResponse\"0\x82\xd3\xe4\x93\x02*:\x01*\"%/v1/collection/{collection_id}/object\x12\xcd\x01\n\x0cGetUploadURL\x12\x32.aruna.api.storage.services.v1.GetUploadURLRequest\x1a\x33.aruna.api.storage.services.v1.GetUploadURLResponse\"T\x82\xd3\xe4\x93\x02N\x12L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/upload\x12\xc1\x01\n\x0eGetDownloadURL\x12\x34.aruna.api.storage.services.v1.GetDownloadURLRequest\x1a\x35.aruna.api.storage.services.v1.GetDownloadURLResponse\"B\x82\xd3\xe4\x93\x02<\x12:/v1/collection/{collection_id}/object/{object_id}/download\x12\xc8\x01\n\x15GetDownloadLinksBatch\x12;.aruna.api.storage.services.v1.GetDownloadLinksBatchRequest\x1a<.aruna.api.storage.services.v1.GetDownloadLinksBatchResponse\"4\x82\xd3\xe4\x93\x02.\x12,/v1/collection/{collection_id}/objects/batch\x12\xda\x01\n\x19\x43reateDownloadLinksStream\x12?.aruna.api.storage.services.v1.CreateDownloadLinksStreamRequest\x1a@.aruna.api.storage.services.v1.CreateDownloadLinksStreamResponse\"8\x82\xd3\xe4\x93\x02\x32:\x01*\"-/v1/collection/{collection_id}/objects/stream0\x01\x12\xe5\x01\n\x13\x46inishObjectStaging\x12\x39.aruna.api.storage.services.v1.FinishObjectStagingRequest\x1a:.aruna.api.storage.services.v1.FinishObjectStagingResponse\"W\x82\xd3\xe4\x93\x02Q:\x01*2L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/finish\x12\xbc\x01\n\x0cUpdateObject\x12\x32.aruna.api.storage.services.v1.UpdateObjectRequest\x1a\x33.aruna.api.storage.services.v1.UpdateObjectResponse\"C\x82\xd3\xe4\x93\x02=:\x01*\"8/v1/collection/{collection_id}/object/{object_id}/update\x12\xf1\x01\n\x15\x43reateObjectReference\x12;.aruna.api.storage.services.v1.CreateObjectReferenceRequest\x1a<.aruna.api.storage.services.v1.CreateObjectReferenceResponse\"]\x82\xd3\xe4\x93\x02W:\x01*\"R/v1/collection/{collection_id}/object/{object_id}/reference/{target_collection_id}\x12\xb8\x01\n\x0b\x43loneObject\x12\x31.aruna.api.storage.services.v1.CloneObjectRequest\x1a\x32.aruna.api.storage.services.v1.CloneObjectResponse\"B\x82\xd3\xe4\x93\x02<:\x01*\"7/v1/collection/{collection_id}/object/{object_id}/clone\x12\xb5\x01\n\x0c\x44\x65leteObject\x12\x32.aruna.api.storage.services.v1.DeleteObjectRequest\x1a\x33.aruna.api.storage.services.v1.DeleteObjectResponse\"<\x82\xd3\xe4\x93\x02\x36:\x01**1/v1/collection/{collection_id}/object/{object_id}\x12\xad\x01\n\rDeleteObjects\x12\x33.aruna.api.storage.services.v1.DeleteObjectsRequest\x1a\x34.aruna.api.storage.services.v1.DeleteObjectsResponse\"1\x82\xd3\xe4\x93\x02+:\x01**&/v1/collection/{collection_id}/objects\x12\xb5\x01\n\rGetObjectByID\x12\x33.aruna.api.storage.services.v1.GetObjectByIDRequest\x1a\x34.aruna.api.storage.services.v1.GetObjectByIDResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/collection/{collection_id}/object/{object_id}\x12\xa1\x01\n\nGetObjects\x12\x30.aruna.api.storage.services.v1.GetObjectsRequest\x1a\x31.aruna.api.storage.services.v1.GetObjectsResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/collection/{collection_id}/objects\x12\xce\x01\n\x12GetObjectRevisions\x12\x38.aruna.api.storage.services.v1.GetObjectRevisionsRequest\x1a\x39.aruna.api.storage.services.v1.GetObjectRevisionsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/v1/collection/{collection_id}/object/{object_id}/revisions\x12\xda\x01\n\x17GetLatestObjectRevision\x12=.aruna.api.storage.services.v1.GetLatestObjectRevisionRequest\x1a>.aruna.api.storage.services.v1.GetLatestObjectRevisionResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/collection/{collection_id}/object/{object_id}/latest\x12\xce\x01\n\x12GetObjectEndpoints\x12\x38.aruna.api.storage.services.v1.GetObjectEndpointsRequest\x1a\x39.aruna.api.storage.services.v1.GetObjectEndpointsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/v1/collection/{collection_id}/object/{object_id}/endpoints\x12\xcf\x01\n\x11\x41\x64\x64LabelsToObject\x12\x37.aruna.api.storage.services.v1.AddLabelsToObjectRequest\x1a\x38.aruna.api.storage.services.v1.AddLabelsToObjectResponse\"G\x82\xd3\xe4\x93\x02\x41:\x01*2</v1/collection/{collection_id}/object/{object_id}/add_labels\x12\xcb\x01\n\x10SetHooksOfObject\x12\x36.aruna.api.storage.services.v1.SetHooksOfObjectRequest\x1a\x37.aruna.api.storage.services.v1.SetHooksOfObjectResponse\"F\x82\xd3\xe4\x93\x02@:\x01*2;/v1/collection/{collection_id}/object/{object_id}/set_hooks\x12\xc0\x01\n\rGetReferences\x12\x33.aruna.api.storage.services.v1.GetReferencesRequest\x1a\x34.aruna.api.storage.services.v1.GetReferencesResponse\"D\x82\xd3\xe4\x93\x02>\x12</v1/collection/{collection_id}/object/{object_id}/referencesB\x8f\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\rObjectServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.object_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\rObjectServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _OBJECTSERVICE.methods_by_name['InitializeNewObject']._options = None
  _OBJECTSERVICE.methods_by_name['InitializeNewObject']._serialized_options = b'\202\323\344\223\002*:\001*\"%/v1/collection/{collection_id}/object'
  _OBJECTSERVICE.methods_by_name['GetUploadURL']._options = None
  _OBJECTSERVICE.methods_by_name['GetUploadURL']._serialized_options = b'\202\323\344\223\002N\022L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/upload'
  _OBJECTSERVICE.methods_by_name['GetDownloadURL']._options = None
  _OBJECTSERVICE.methods_by_name['GetDownloadURL']._serialized_options = b'\202\323\344\223\002<\022:/v1/collection/{collection_id}/object/{object_id}/download'
  _OBJECTSERVICE.methods_by_name['GetDownloadLinksBatch']._options = None
  _OBJECTSERVICE.methods_by_name['GetDownloadLinksBatch']._serialized_options = b'\202\323\344\223\002.\022,/v1/collection/{collection_id}/objects/batch'
  _OBJECTSERVICE.methods_by_name['CreateDownloadLinksStream']._options = None
  _OBJECTSERVICE.methods_by_name['CreateDownloadLinksStream']._serialized_options = b'\202\323\344\223\0022:\001*\"-/v1/collection/{collection_id}/objects/stream'
  _OBJECTSERVICE.methods_by_name['FinishObjectStaging']._options = None
  _OBJECTSERVICE.methods_by_name['FinishObjectStaging']._serialized_options = b'\202\323\344\223\002Q:\001*2L/v1/collection/{collection_id}/object/{object_id}/staging/{upload_id}/finish'
  _OBJECTSERVICE.methods_by_name['UpdateObject']._options = None
  _OBJECTSERVICE.methods_by_name['UpdateObject']._serialized_options = b'\202\323\344\223\002=:\001*\"8/v1/collection/{collection_id}/object/{object_id}/update'
  _OBJECTSERVICE.methods_by_name['CreateObjectReference']._options = None
  _OBJECTSERVICE.methods_by_name['CreateObjectReference']._serialized_options = b'\202\323\344\223\002W:\001*\"R/v1/collection/{collection_id}/object/{object_id}/reference/{target_collection_id}'
  _OBJECTSERVICE.methods_by_name['CloneObject']._options = None
  _OBJECTSERVICE.methods_by_name['CloneObject']._serialized_options = b'\202\323\344\223\002<:\001*\"7/v1/collection/{collection_id}/object/{object_id}/clone'
  _OBJECTSERVICE.methods_by_name['DeleteObject']._options = None
  _OBJECTSERVICE.methods_by_name['DeleteObject']._serialized_options = b'\202\323\344\223\0026:\001**1/v1/collection/{collection_id}/object/{object_id}'
  _OBJECTSERVICE.methods_by_name['DeleteObjects']._options = None
  _OBJECTSERVICE.methods_by_name['DeleteObjects']._serialized_options = b'\202\323\344\223\002+:\001**&/v1/collection/{collection_id}/objects'
  _OBJECTSERVICE.methods_by_name['GetObjectByID']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectByID']._serialized_options = b'\202\323\344\223\0023\0221/v1/collection/{collection_id}/object/{object_id}'
  _OBJECTSERVICE.methods_by_name['GetObjects']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjects']._serialized_options = b'\202\323\344\223\002(\022&/v1/collection/{collection_id}/objects'
  _OBJECTSERVICE.methods_by_name['GetObjectRevisions']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectRevisions']._serialized_options = b'\202\323\344\223\002=\022;/v1/collection/{collection_id}/object/{object_id}/revisions'
  _OBJECTSERVICE.methods_by_name['GetLatestObjectRevision']._options = None
  _OBJECTSERVICE.methods_by_name['GetLatestObjectRevision']._serialized_options = b'\202\323\344\223\002:\0228/v1/collection/{collection_id}/object/{object_id}/latest'
  _OBJECTSERVICE.methods_by_name['GetObjectEndpoints']._options = None
  _OBJECTSERVICE.methods_by_name['GetObjectEndpoints']._serialized_options = b'\202\323\344\223\002=\022;/v1/collection/{collection_id}/object/{object_id}/endpoints'
  _OBJECTSERVICE.methods_by_name['AddLabelsToObject']._options = None
  _OBJECTSERVICE.methods_by_name['AddLabelsToObject']._serialized_options = b'\202\323\344\223\002A:\001*2</v1/collection/{collection_id}/object/{object_id}/add_labels'
  _OBJECTSERVICE.methods_by_name['SetHooksOfObject']._options = None
  _OBJECTSERVICE.methods_by_name['SetHooksOfObject']._serialized_options = b'\202\323\344\223\002@:\001*2;/v1/collection/{collection_id}/object/{object_id}/set_hooks'
  _OBJECTSERVICE.methods_by_name['GetReferences']._options = None
  _OBJECTSERVICE.methods_by_name['GetReferences']._serialized_options = b'\202\323\344\223\002>\022</v1/collection/{collection_id}/object/{object_id}/references'
  _URL._serialized_start=198
  _URL._serialized_end=221
  _STAGEOBJECT._serialized_start=224
  _STAGEOBJECT._serialized_end=624
  _INITIALIZENEWOBJECTREQUEST._serialized_start=627
  _INITIALIZENEWOBJECTREQUEST._serialized_end=885
  _INITIALIZENEWOBJECTRESPONSE._serialized_start=887
  _INITIALIZENEWOBJECTRESPONSE._serialized_end=1011
  _GETUPLOADURLREQUEST._serialized_start=1014
  _GETUPLOADURLREQUEST._serialized_end=1193
  _GETUPLOADURLRESPONSE._serialized_start=1195
  _GETUPLOADURLRESPONSE._serialized_end=1271
  _COMPLETEDPARTS._serialized_start=1273
  _COMPLETEDPARTS._serialized_end=1329
  _GETDOWNLOADURLREQUEST._serialized_start=1331
  _GETDOWNLOADURLREQUEST._serialized_end=1420
  _GETDOWNLOADURLRESPONSE._serialized_start=1422
  _GETDOWNLOADURLRESPONSE._serialized_end=1500
  _GETDOWNLOADLINKSBATCHREQUEST._serialized_start=1502
  _GETDOWNLOADLINKSBATCHREQUEST._serialized_end=1595
  _GETDOWNLOADLINKSBATCHRESPONSE._serialized_start=1597
  _GETDOWNLOADLINKSBATCHRESPONSE._serialized_end=1684
  _CREATEDOWNLOADLINKSSTREAMREQUEST._serialized_start=1686
  _CREATEDOWNLOADLINKSSTREAMREQUEST._serialized_end=1783
  _CREATEDOWNLOADLINKSSTREAMRESPONSE._serialized_start=1785
  _CREATEDOWNLOADLINKSSTREAMRESPONSE._serialized_end=1874
  _FINISHOBJECTSTAGINGREQUEST._serialized_start=1877
  _FINISHOBJECTSTAGINGREQUEST._serialized_end=2205
  _FINISHOBJECTSTAGINGRESPONSE._serialized_start=2207
  _FINISHOBJECTSTAGINGRESPONSE._serialized_end=2297
  _UPDATEOBJECTREQUEST._serialized_start=2300
  _UPDATEOBJECTREQUEST._serialized_end=2631
  _UPDATEOBJECTRESPONSE._serialized_start=2633
  _UPDATEOBJECTRESPONSE._serialized_end=2752
  _CREATEOBJECTREFERENCEREQUEST._serialized_start=2755
  _CREATEOBJECTREFERENCEREQUEST._serialized_end=2964
  _CREATEOBJECTREFERENCERESPONSE._serialized_start=2966
  _CREATEOBJECTREFERENCERESPONSE._serialized_end=2997
  _CLONEOBJECTREQUEST._serialized_start=3000
  _CLONEOBJECTREQUEST._serialized_end=3136
  _CLONEOBJECTRESPONSE._serialized_start=3138
  _CLONEOBJECTRESPONSE._serialized_end=3220
  _DELETEOBJECTREQUEST._serialized_start=3223
  _DELETEOBJECTREQUEST._serialized_end=3371
  _DELETEOBJECTRESPONSE._serialized_start=3373
  _DELETEOBJECTRESPONSE._serialized_end=3395
  _DELETEOBJECTSREQUEST._serialized_start=3398
  _DELETEOBJECTSREQUEST._serialized_end=3549
  _DELETEOBJECTSRESPONSE._serialized_start=3551
  _DELETEOBJECTSRESPONSE._serialized_end=3574
  _OBJECTWITHURL._serialized_start=3576
  _OBJECTWITHURL._serialized_end=3670
  _GETOBJECTBYIDREQUEST._serialized_start=3672
  _GETOBJECTBYIDREQUEST._serialized_end=3787
  _GETOBJECTBYIDRESPONSE._serialized_start=3789
  _GETOBJECTBYIDRESPONSE._serialized_end=3882
  _GETOBJECTSREQUEST._serialized_start=3885
  _GETOBJECTSREQUEST._serialized_end=4130
  _GETOBJECTSRESPONSE._serialized_start=4132
  _GETOBJECTSRESPONSE._serialized_end=4224
  _GETOBJECTREVISIONSREQUEST._serialized_start=4227
  _GETOBJECTREVISIONSREQUEST._serialized_end=4424
  _GETOBJECTREVISIONSRESPONSE._serialized_start=4426
  _GETOBJECTREVISIONSRESPONSE._serialized_end=4526
  _GETLATESTOBJECTREVISIONREQUEST._serialized_start=4528
  _GETLATESTOBJECTREVISIONREQUEST._serialized_end=4626
  _GETLATESTOBJECTREVISIONRESPONSE._serialized_start=4628
  _GETLATESTOBJECTREVISIONRESPONSE._serialized_end=4722
  _GETOBJECTENDPOINTSREQUEST._serialized_start=4724
  _GETOBJECTENDPOINTSREQUEST._serialized_end=4817
  _GETOBJECTENDPOINTSRESPONSE._serialized_start=4819
  _GETOBJECTENDPOINTSRESPONSE._serialized_end=4916
  _ADDLABELSTOOBJECTREQUEST._serialized_start=4919
  _ADDLABELSTOOBJECTREQUEST._serialized_end=5086
  _ADDLABELSTOOBJECTRESPONSE._serialized_start=5088
  _ADDLABELSTOOBJECTRESPONSE._serialized_end=5176
  _SETHOOKSOFOBJECTREQUEST._serialized_start=5179
  _SETHOOKSOFOBJECTREQUEST._serialized_end=5331
  _SETHOOKSOFOBJECTRESPONSE._serialized_start=5333
  _SETHOOKSOFOBJECTRESPONSE._serialized_end=5420
  _GETREFERENCESREQUEST._serialized_start=5422
  _GETREFERENCESREQUEST._serialized_end=5549
  _OBJECTREFERENCE._serialized_start=5552
  _OBJECTREFERENCE._serialized_end=5711
  _GETREFERENCESRESPONSE._serialized_start=5713
  _GETREFERENCESRESPONSE._serialized_end=5816
  _OBJECTSERVICE._serialized_start=5819
  _OBJECTSERVICE._serialized_end=9667
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.internal.v1 import proxy_pb2 as aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2


class InternalProxyServiceStub(object):
    """Definition for the internal API that is used to communicate with all internal
    components.

    All uploads should follow this procedure:
    1. Init a new upload.
    2. Create a Upload Presigned URL (The URL should contain a specifier for the
    upload and part id)
    3. Use the presigned URL to upload individual parts, 1-x times.
    4. When all parts are uploaded, call FinishPresignedUpload to complete the
    upload and provide the parts list.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitPresignedUpload = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/InitPresignedUpload',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitPresignedUploadRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitPresignedUploadResponse.FromString,
                )
        self.CreatePresignedUploadUrl = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/CreatePresignedUploadUrl',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedUploadUrlRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedUploadUrlResponse.FromString,
                )
        self.FinishPresignedUpload = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/FinishPresignedUpload',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishPresignedUploadRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishPresignedUploadResponse.FromString,
                )
        self.CreatePresignedDownload = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/CreatePresignedDownload',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedDownloadRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedDownloadResponse.FromString,
                )
        self.CreateBucket = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/CreateBucket',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreateBucketRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreateBucketResponse.FromString,
                )


class InternalProxyServiceServicer(object):
    """Definition for the internal API that is used to communicate with all internal
    components.

    All uploads should follow this procedure:
    1. Init a new upload.
    2. Create a Upload Presigned URL (The URL should contain a specifier for the
    upload and part id)
    3. Use the presigned URL to upload individual parts, 1-x times.
    4. When all parts are uploaded, call FinishPresignedUpload to complete the
    upload and provide the parts list.

    """

    def InitPresignedUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePresignedUploadUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinishPresignedUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePresignedDownload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBucket(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InternalProxyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitPresignedUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.InitPresignedUpload,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitPresignedUploadRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitPresignedUploadResponse.SerializeToString,
            ),
            'CreatePresignedUploadUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePresignedUploadUrl,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedUploadUrlRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedUploadUrlResponse.SerializeToString,
            ),
            'FinishPresignedUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.FinishPresignedUpload,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishPresignedUploadRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishPresignedUploadResponse.SerializeToString,
            ),
            'CreatePresignedDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePresignedDownload,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedDownloadRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedDownloadResponse.SerializeToString,
            ),
            'CreateBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBucket,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreateBucketRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreateBucketResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.internal.v1.InternalProxyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InternalProxyService(object):
    """Definition for the internal API that is used to communicate with all internal
    components.

    All uploads should follow this procedure:
    1. Init a new upload.
    2. Create a Upload Presigned URL (The URL should contain a specifier for the
    upload and part id)
    3. Use the presigned URL to upload individual parts, 1-x times.
    4. When all parts are uploaded, call FinishPresignedUpload to complete the
    upload and provide the parts list.

    """

    @staticmethod
    def InitPresignedUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/InitPresignedUpload',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitPresignedUploadRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitPresignedUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePresignedUploadUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/CreatePresignedUploadUrl',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedUploadUrlRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedUploadUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinishPresignedUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/FinishPresignedUpload',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishPresignedUploadRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishPresignedUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePresignedDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/CreatePresignedDownload',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedDownloadRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreatePresignedDownloadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/CreateBucket',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreateBucketRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.CreateBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.api import visibility_pb2 as _visibility_pb2
from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Authorization(_message.Message):
    __slots__ = ["accesskey", "is_token", "secretkey"]
    ACCESSKEY_FIELD_NUMBER: _ClassVar[int]
    IS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SECRETKEY_FIELD_NUMBER: _ClassVar[int]
    accesskey: str
    is_token: bool
    secretkey: str
    def __init__(self, secretkey: _Optional[str] = ..., accesskey: _Optional[str] = ..., is_token: bool = ...) -> None: ...

class AuthorizeRequest(_message.Message):
    __slots__ = ["resource", "resource_action", "resource_id"]
    RESOURCE_ACTION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    resource: _models_pb2.ResourceType
    resource_action: _models_pb2.ResourceAction
    resource_id: str
    def __init__(self, resource: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., resource_action: _Optional[_Union[_models_pb2.ResourceAction, str]] = ...) -> None: ...

class AuthorizeResponse(_message.Message):
    __slots__ = ["ok"]
    OK_FIELD_NUMBER: _ClassVar[int]
    ok: bool
    def __init__(self, ok: bool = ...) -> None: ...



from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
LOCATION_TYPE_FILE: LocationType
LOCATION_TYPE_S3: LocationType
LOCATION_TYPE_UNSPECIFIED: LocationType

class CreateBucketRequest(_message.Message):
    __slots__ = ["bucket_name"]
    BUCKET_NAME_FIELD_NUMBER: _ClassVar[int]
    bucket_name: str
    def __init__(self, bucket_name: _Optional[str] = ...) -> None: ...

class CreateBucketResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreatePresignedDownloadRequest(_message.Message):
    __slots__ = ["filename", "is_public", "location", "range"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    filename: str
    is_public: bool
    location: Location
    range: Range
    def __init__(self, location: _Optional[_Union[Location, _Mapping]] = ..., is_public: bool = ..., range: _Optional[_Union[Range, _Mapping]] = ..., filename: _Optional[str] = ...) -> None: ...

class CreatePresignedDownloadResponse(_message.Message):
    __slots__ = ["url"]
    URL_FIELD_NUMBER: _ClassVar[int]
    url: str
    def __init__(self, url: _Optional[str] = ...) -> None: ...

class CreatePresignedUploadUrlRequest(_message.Message):
    __slots__ = ["location", "multipart", "part_number", "upload_id"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    location: Location
    multipart: bool
    part_number: int
    upload_id: str
    def __init__(self, location: _Optional[_Union[Location, _Mapping]] = ..., upload_id: _Optional[str] = ..., part_number: _Optional[int] = ..., multipart: bool = ...) -> None: ...

class CreatePresignedUploadUrlResponse(_message.Message):
    __slots__ = ["url"]
    URL_FIELD_NUMBER: _ClassVar[int]
    url: str
    def __init__(self, url: _Optional[str] = ...) -> None: ...

class FinishPresignedUploadRequest(_message.Message):
    __slots__ = ["bucket", "key", "multipart", "part_etags", "upload_id"]
    BUCKET_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_FIELD_NUMBER: _ClassVar[int]
    PART_ETAGS_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    bucket: str
    key: str
    multipart: bool
    part_etags: _containers.RepeatedCompositeFieldContainer[PartETag]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., part_etags: _Optional[_Iterable[_Union[PartETag, _Mapping]]] = ..., bucket: _Optional[str] = ..., key: _Optional[str] = ..., multipart: bool = ...) -> None: ...

class FinishPresignedUploadResponse(_message.Message):
    __slots__ = ["ok"]
    OK_FIELD_NUMBER: _ClassVar[int]
    ok: bool
    def __init__(self, ok: bool = ...) -> None: ...

class InitPresignedUploadRequest(_message.Message):
    __slots__ = ["location", "multipart"]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_FIELD_NUMBER: _ClassVar[int]
    location: Location
    multipart: bool
    def __init__(self, location: _Optional[_Union[Location, _Mapping]] = ..., multipart: bool = ...) -> None: ...

class InitPresignedUploadResponse(_message.Message):
    __slots__ = ["upload_id"]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ...) -> None: ...

class Location(_message.Message):
    __slots__ = ["bucket", "path", "type"]
    BUCKET_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    bucket: str
    path: str
    type: LocationType
    def __init__(self, type: _Optional[_Union[LocationType, str]] = ..., bucket: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...

class PartETag(_message.Message):
    __slots__ = ["etag", "part_number"]
    ETAG_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    etag: str
    part_number: int
    def __init__(self, part_number: _Optional[int] = ..., etag: _Optional[str] = ...) -> None: ...

class Range(_message.Message):
    __slots__ = ["end", "start"]
    END_FIELD_NUMBER: _ClassVar[int]
    START_FIELD_NUMBER: _ClassVar[int]
    end: int
    start: int
    def __init__(self, start: _Optional[int] = ..., end: _Optional[int] = ...) -> None: ...

class LocationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
EVENT_TYPE_ALL: EventType
EVENT_TYPE_AVAILABLE: EventType
EVENT_TYPE_CREATED: EventType
EVENT_TYPE_DELETED: EventType
EVENT_TYPE_METADATA_UPDATED: EventType
EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_UPDATED: EventType

class CreateEventStreamingGroupRequest(_message.Message):
    __slots__ = ["include_subresource", "resource", "resource_id", "stream_all", "stream_from_date", "stream_from_sequence", "stream_group_id"]
    INCLUDE_SUBRESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    STREAM_ALL_FIELD_NUMBER: _ClassVar[int]
    STREAM_FROM_DATE_FIELD_NUMBER: _ClassVar[int]
    STREAM_FROM_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    include_subresource: bool
    resource: _models_pb2.ResourceType
    resource_id: str
    stream_all: StreamAll
    stream_from_date: StreamFromDate
    stream_from_sequence: StreamFromSequence
    stream_group_id: str
    def __init__(self, resource: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., include_subresource: bool = ..., stream_all: _Optional[_Union[StreamAll, _Mapping]] = ..., stream_from_date: _Optional[_Union[StreamFromDate, _Mapping]] = ..., stream_from_sequence: _Optional[_Union[StreamFromSequence, _Mapping]] = ..., stream_group_id: _Optional[str] = ...) -> None: ...

class CreateEventStreamingGroupResponse(_message.Message):
    __slots__ = ["stream_group_id"]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    stream_group_id: str
    def __init__(self, stream_group_id: _Optional[str] = ...) -> None: ...

class DeleteEventStreamingGroupRequest(_message.Message):
    __slots__ = ["stream_group_id"]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    stream_group_id: str
    def __init__(self, stream_group_id: _Optional[str] = ...) -> None: ...

class DeleteEventStreamingGroupResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EventNotificationMessage(_message.Message):
    __slots__ = ["resource", "resource_id", "updated_type"]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATED_TYPE_FIELD_NUMBER: _ClassVar[int]
    resource: _models_pb2.ResourceType
    resource_id: str
    updated_type: EventType
    def __init__(self, resource: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., updated_type: _Optional[_Union[EventType, str]] = ...) -> None: ...

class NotficationStreamAck(_message.Message):
    __slots__ = ["ack_chunk_id"]
    ACK_CHUNK_ID_FIELD_NUMBER: _ClassVar[int]
    ack_chunk_id: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ack_chunk_id: _Optional[_Iterable[str]] = ...) -> None: ...

class NotificationStreamInit(_message.Message):
    __slots__ = ["stream_group_id"]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    stream_group_id: str
    def __init__(self, stream_group_id: _Optional[str] = ...) -> None: ...

class NotificationStreamResponse(_message.Message):
    __slots__ = ["message", "sequence", "timestamp"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    message: EventNotificationMessage
    sequence: int
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, message: _Optional[_Union[EventNotificationMessage, _Mapping]] = ..., sequence: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ReadStreamGroupMessagesRequest(_message.Message):
    __slots__ = ["ack", "close", "init"]
    ACK_FIELD_NUMBER: _ClassVar[int]
    CLOSE_FIELD_NUMBER: _ClassVar[int]
    INIT_FIELD_NUMBER: _ClassVar[int]
    ack: NotficationStreamAck
    close: bool
    init: NotificationStreamInit
    def __init__(self, init: _Optional[_Union[NotificationStreamInit, _Mapping]] = ..., ack: _Optional[_Union[NotficationStreamAck, _Mapping]] = ..., close: bool = ...) -> None: ...

class ReadStreamGroupMessagesResponse(_message.Message):
    __slots__ = ["ack_chunk_id", "notification"]
    ACK_CHUNK_ID_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    ack_chunk_id: str
    notification: _containers.RepeatedCompositeFieldContainer[NotificationStreamResponse]
    def __init__(self, notification: _Optional[_Iterable[_Union[NotificationStreamResponse, _Mapping]]] = ..., ack_chunk_id: _Optional[str] = ...) -> None: ...

class StreamAll(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StreamFromDate(_message.Message):
    __slots__ = ["timestamp"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class StreamFromSequence(_message.Message):
    __slots__ = ["sequence"]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    sequence: int
    def __init__(self, sequence: _Optional[int] = ...) -> None: ...

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/internal/v1/proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aruna/api/internal/v1/proxy.proto\x12\x15\x61runa.api.internal.v1\x1a\x1bgoogle/api/visibility.proto\"o\n\x08Location\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32#.aruna.api.internal.v1.LocationTypeR\x04type\x12\x16\n\x06\x62ucket\x18\x02 \x01(\tR\x06\x62ucket\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\"?\n\x08PartETag\x12\x1f\n\x0bpart_number\x18\x01 \x01(\x03R\npartNumber\x12\x12\n\x04\x65tag\x18\x02 \x01(\tR\x04\x65tag\"w\n\x1aInitPresignedUploadRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x1c\n\tmultipart\x18\x02 \x01(\x08R\tmultipart\":\n\x1bInitPresignedUploadResponse\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\"\xba\x01\n\x1f\x43reatePresignedUploadUrlRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x1b\n\tupload_id\x18\x02 \x01(\tR\x08uploadId\x12\x1f\n\x0bpart_number\x18\x03 \x01(\x03R\npartNumber\x12\x1c\n\tmultipart\x18\x04 \x01(\x08R\tmultipart\"4\n CreatePresignedUploadUrlResponse\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"\xc3\x01\n\x1c\x46inishPresignedUploadRequest\x12\x1b\n\tupload_id\x18\x01 \x01(\tR\x08uploadId\x12>\n\npart_etags\x18\x02 \x03(\x0b\x32\x1f.aruna.api.internal.v1.PartETagR\tpartEtags\x12\x16\n\x06\x62ucket\x18\x03 \x01(\tR\x06\x62ucket\x12\x10\n\x03key\x18\x04 \x01(\tR\x03key\x12\x1c\n\tmultipart\x18\x05 \x01(\x08R\tmultipart\"/\n\x1d\x46inishPresignedUploadResponse\x12\x0e\n\x02ok\x18\x01 \x01(\x08R\x02ok\"/\n\x05Range\x12\x14\n\x05start\x18\x01 \x01(\x03R\x05start\x12\x10\n\x03\x65nd\x18\x02 \x01(\x03R\x03\x65nd\"\xca\x01\n\x1e\x43reatePresignedDownloadRequest\x12;\n\x08location\x18\x01 \x01(\x0b\x32\x1f.aruna.api.internal.v1.LocationR\x08location\x12\x1b\n\tis_public\x18\x02 \x01(\x08R\x08isPublic\x12\x32\n\x05range\x18\x03 \x01(\x0b\x32\x1c.aruna.api.internal.v1.RangeR\x05range\x12\x1a\n\x08\x66ilename\x18\x04 \x01(\tR\x08\x66ilename\"3\n\x1f\x43reatePresignedDownloadResponse\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\"6\n\x13\x43reateBucketRequest\x12\x1f\n\x0b\x62ucket_name\x18\x01 \x01(\tR\nbucketName\"\x16\n\x14\x43reateBucketResponse*[\n\x0cLocationType\x12\x1d\n\x19LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10LOCATION_TYPE_S3\x10\x01\x12\x16\n\x12LOCATION_TYPE_FILE\x10\x02\x32\xb7\x05\n\x14InternalProxyService\x12~\n\x13InitPresignedUpload\x12\x31.aruna.api.internal.v1.InitPresignedUploadRequest\x1a\x32.aruna.api.internal.v1.InitPresignedUploadResponse\"\x00\x12\x8d\x01\n\x18\x43reatePresignedUploadUrl\x12\x36.aruna.api.internal.v1.CreatePresignedUploadUrlRequest\x1a\x37.aruna.api.internal.v1.CreatePresignedUploadUrlResponse\"\x00\x12\x84\x01\n\x15\x46inishPresignedUpload\x12\x33.aruna.api.internal.v1.FinishPresignedUploadRequest\x1a\x34.aruna.api.internal.v1.FinishPresignedUploadResponse\"\x00\x12\x8a\x01\n\x17\x43reatePresignedDownload\x12\x35.aruna.api.internal.v1.CreatePresignedDownloadRequest\x1a\x36.aruna.api.internal.v1.CreatePresignedDownloadResponse\"\x00\x12i\n\x0c\x43reateBucket\x12*.aruna.api.internal.v1.CreateBucketRequest\x1a+.aruna.api.internal.v1.CreateBucketResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB6Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.internal.v1.proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1'
  _INTERNALPROXYSERVICE._options = None
  _INTERNALPROXYSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _LOCATIONTYPE._serialized_start=1325
  _LOCATIONTYPE._serialized_end=1416
  _LOCATION._serialized_start=89
  _LOCATION._serialized_end=200
  _PARTETAG._serialized_start=202
  _PARTETAG._serialized_end=265
  _INITPRESIGNEDUPLOADREQUEST._serialized_start=267
  _INITPRESIGNEDUPLOADREQUEST._serialized_end=386
  _INITPRESIGNEDUPLOADRESPONSE._serialized_start=388
  _INITPRESIGNEDUPLOADRESPONSE._serialized_end=446
  _CREATEPRESIGNEDUPLOADURLREQUEST._serialized_start=449
  _CREATEPRESIGNEDUPLOADURLREQUEST._serialized_end=635
  _CREATEPRESIGNEDUPLOADURLRESPONSE._serialized_start=637
  _CREATEPRESIGNEDUPLOADURLRESPONSE._serialized_end=689
  _FINISHPRESIGNEDUPLOADREQUEST._serialized_start=692
  _FINISHPRESIGNEDUPLOADREQUEST._serialized_end=887
  _FINISHPRESIGNEDUPLOADRESPONSE._serialized_start=889
  _FINISHPRESIGNEDUPLOADRESPONSE._serialized_end=936
  _RANGE._serialized_start=938
  _RANGE._serialized_end=985
  _CREATEPRESIGNEDDOWNLOADREQUEST._serialized_start=988
  _CREATEPRESIGNEDDOWNLOADREQUEST._serialized_end=1190
  _CREATEPRESIGNEDDOWNLOADRESPONSE._serialized_start=1192
  _CREATEPRESIGNEDDOWNLOADRESPONSE._serialized_end=1243
  _CREATEBUCKETREQUEST._serialized_start=1245
  _CREATEBUCKETREQUEST._serialized_end=1299
  _CREATEBUCKETRESPONSE._serialized_start=1301
  _CREATEBUCKETRESPONSE._serialized_end=1323
  _INTERNALPROXYSERVICE._serialized_start=1419
  _INTERNALPROXYSERVICE._serialized_end=2114
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/notification/services/v1/notification_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=aruna/api/notification/services/v1/notification_service.proto\x12\"aruna.api.notification.services.v1\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(aruna/api/storage/models/v1/models.proto\"\x8e\x04\n CreateEventStreamingGroupRequest\x12\x45\n\x08resource\x18\x01 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x08resource\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\x12/\n\x13include_subresource\x18\x03 \x01(\x08R\x12includeSubresource\x12N\n\nstream_all\x18\x04 \x01(\x0b\x32-.aruna.api.notification.services.v1.StreamAllH\x00R\tstreamAll\x12^\n\x10stream_from_date\x18\x05 \x01(\x0b\x32\x32.aruna.api.notification.services.v1.StreamFromDateH\x00R\x0estreamFromDate\x12j\n\x14stream_from_sequence\x18\x06 \x01(\x0b\x32\x36.aruna.api.notification.services.v1.StreamFromSequenceH\x00R\x12streamFromSequence\x12&\n\x0fstream_group_id\x18\x07 \x01(\tR\rstreamGroupIdB\r\n\x0bstream_type\"K\n!CreateEventStreamingGroupResponse\x12&\n\x0fstream_group_id\x18\x01 \x01(\tR\rstreamGroupId\"\xe7\x01\n\x1eReadStreamGroupMessagesRequest\x12P\n\x04init\x18\x01 \x01(\x0b\x32:.aruna.api.notification.services.v1.NotificationStreamInitH\x00R\x04init\x12L\n\x03\x61\x63k\x18\x02 \x01(\x0b\x32\x38.aruna.api.notification.services.v1.NotficationStreamAckH\x00R\x03\x61\x63k\x12\x14\n\x05\x63lose\x18\x03 \x01(\x08R\x05\x63loseB\x0f\n\rstream_action\"J\n DeleteEventStreamingGroupRequest\x12&\n\x0fstream_group_id\x18\x01 \x01(\tR\rstreamGroupId\"#\n!DeleteEventStreamingGroupResponse\"@\n\x16NotificationStreamInit\x12&\n\x0fstream_group_id\x18\x01 \x01(\tR\rstreamGroupId\"8\n\x14NotficationStreamAck\x12 \n\x0c\x61\x63k_chunk_id\x18\x01 \x03(\tR\nackChunkId\"\xa7\x01\n\x1fReadStreamGroupMessagesResponse\x12\x62\n\x0cnotification\x18\x01 \x03(\x0b\x32>.aruna.api.notification.services.v1.NotificationStreamResponseR\x0cnotification\x12 \n\x0c\x61\x63k_chunk_id\x18\x02 \x01(\tR\nackChunkId\"0\n\x12StreamFromSequence\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\"J\n\x0eStreamFromDate\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x0b\n\tStreamAll\"\xca\x01\n\x1aNotificationStreamResponse\x12V\n\x07message\x18\x01 \x01(\x0b\x32<.aruna.api.notification.services.v1.EventNotificationMessageR\x07message\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\xd4\x01\n\x18\x45ventNotificationMessage\x12\x45\n\x08resource\x18\x01 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x08resource\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\x12P\n\x0cupdated_type\x18\x03 \x01(\x0e\x32-.aruna.api.notification.services.v1.EventTypeR\x0bupdatedType*\xbe\x01\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x45VENT_TYPE_CREATED\x10\x01\x12\x18\n\x14\x45VENT_TYPE_AVAILABLE\x10\x02\x12\x16\n\x12\x45VENT_TYPE_UPDATED\x10\x03\x12\x1f\n\x1b\x45VENT_TYPE_METADATA_UPDATED\x10\x04\x12\x16\n\x12\x45VENT_TYPE_DELETED\x10\x05\x12\x12\n\x0e\x45VENT_TYPE_ALL\x10\x06\x32\xb4\x04\n\x19UpdateNotificationService\x12\xaa\x01\n\x19\x43reateEventStreamingGroup\x12\x44.aruna.api.notification.services.v1.CreateEventStreamingGroupRequest\x1a\x45.aruna.api.notification.services.v1.CreateEventStreamingGroupResponse\"\x00\x12\xaa\x01\n\x19\x44\x65leteEventStreamingGroup\x12\x44.aruna.api.notification.services.v1.DeleteEventStreamingGroupRequest\x1a\x45.aruna.api.notification.services.v1.DeleteEventStreamingGroupResponse\"\x00\x12\xa8\x01\n\x17ReadStreamGroupMessages\x12\x42.aruna.api.notification.services.v1.ReadStreamGroupMessagesRequest\x1a\x43.aruna.api.notification.services.v1.ReadStreamGroupMessagesResponse\"\x00(\x01\x30\x01\x1a\x12\xfa\xd2\xe4\x93\x02\x0c\x12\nUNFINISHEDB\x9c\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x1aUpdateNotificationServicesP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.notification.services.v1.notification_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\032UpdateNotificationServicesP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _UPDATENOTIFICATIONSERVICE._options = None
  _UPDATENOTIFICATIONSERVICE._serialized_options = b'\372\322\344\223\002\014\022\nUNFINISHED'
  _EVENTTYPE._serialized_start=2012
  _EVENTTYPE._serialized_end=2202
  _CREATEEVENTSTREAMINGGROUPREQUEST._serialized_start=206
  _CREATEEVENTSTREAMINGGROUPREQUEST._serialized_end=732
  _CREATEEVENTSTREAMINGGROUPRESPONSE._serialized_start=734
  _CREATEEVENTSTREAMINGGROUPRESPONSE._serialized_end=809
  _READSTREAMGROUPMESSAGESREQUEST._serialized_start=812
  _READSTREAMGROUPMESSAGESREQUEST._serialized_end=1043
  _DELETEEVENTSTREAMINGGROUPREQUEST._serialized_start=1045
  _DELETEEVENTSTREAMINGGROUPREQUEST._serialized_end=1119
  _DELETEEVENTSTREAMINGGROUPRESPONSE._serialized_start=1121
  _DELETEEVENTSTREAMINGGROUPRESPONSE._serialized_end=1156
  _NOTIFICATIONSTREAMINIT._serialized_start=1158
  _NOTIFICATIONSTREAMINIT._serialized_end=1222
  _NOTFICATIONSTREAMACK._serialized_start=1224
  _NOTFICATIONSTREAMACK._serialized_end=1280
  _READSTREAMGROUPMESSAGESRESPONSE._serialized_start=1283
  _READSTREAMGROUPMESSAGESRESPONSE._serialized_end=1450
  _STREAMFROMSEQUENCE._serialized_start=1452
  _STREAMFROMSEQUENCE._serialized_end=1500
  _STREAMFROMDATE._serialized_start=1502
  _STREAMFROMDATE._serialized_end=1576
  _STREAMALL._serialized_start=1578
  _STREAMALL._serialized_end=1589
  _NOTIFICATIONSTREAMRESPONSE._serialized_start=1592
  _NOTIFICATIONSTREAMRESPONSE._serialized_end=1794
  _EVENTNOTIFICATIONMESSAGE._serialized_start=1797
  _EVENTNOTIFICATIONMESSAGE._serialized_end=2009
  _UPDATENOTIFICATIONSERVICE._serialized_start=2205
  _UPDATENOTIFICATIONSERVICE._serialized_end=2769
# @@protoc_insertion_point(module_scope)
